@@ -7,53 +7,52 @@
 ##'
 ##' The AR(1) coefficients are computed by \code{\link[stats]{arima}}.
 ##'
-##' @param x univariate time-series (a single numerical vector); default to be
-##'   \code{sin(seq(0, 2 * pi, length = 50)) + rnorm(50, sd = 0.2)}
+##' @param x univariate time-series (a single numerical vector);
+##' default to be \code{sin(seq(0, 2 * pi, length = 50)) + rnorm(50,
+##' sd = 0.2)}
 ##' @param k an integer of the window width
-##' @param conf a positive number: the confidence intervals are computed as
-##'   [ar1 - conf*s.e., ar1 + conf*s.e.]
+##' @param conf a positive number: the confidence intervals are
+##' computed as \code{c(ar1 - conf*s.e., ar1 + conf*s.e.)}
 ##' @param mat,widths,heights arguments passed to
-##'   \code{\link[graphics]{layout}} to divide the device into 2 parts
-##' @param lty.rect the line type of the rectangles respresenting the moving
-##'   ``windows''
-##' @param \dots other arguments passed to \code{\link[graphics]{points}} in
-##'   the bottom plot (the centers of the arrows)
-##' @return A list containing \item{phi }{the AR(1) coefficients} \item{L
-##'   }{lower bound of the confidence interval} \item{U }{upper bound of the
-##'   confidence interval}
+##' \code{\link[graphics]{layout}} to divide the device into 2 parts
+##' @param lty.rect the line type of the rectangles respresenting the
+##' moving ``windows''
+##' @param \dots other arguments passed to
+##' \code{\link[graphics]{points}} in the bottom plot (the centers of
+##' the arrows)
+##' @return A list containing \item{phi }{the AR(1) coefficients}
+##' \item{L }{lower bound of the confidence interval} \item{U }{upper
+##' bound of the confidence interval}
 ##' @author Yihui Xie <\url{http://yihui.name}>
 ##' @seealso \code{\link[stats]{arima}}
-##' @references Robert A. Meyer, Jr. Estimating coefficients that change over
-##'   time. \emph{International Economic Review}, 13(3):705-710, 1972.
+##' @references Robert A. Meyer, Jr. Estimating coefficients that
+##' change over time. \emph{International Economic Review},
+##' 13(3):705-710, 1972.
 ##'
 ##' \url{http://animation.yihui.name/ts:moving_window_ar}
 ##' @keywords dplot dynamic ts
 ##' @examples
 ##'
-##' # moving window along a sin curve
-##' oopt = ani.options(interval = 0.1, nmax = 50)
-##' op = par(mar = c(2, 3, 1, 0.5), mgp = c(1.5, 0.5, 0))
+##' ## moving window along a sin curve
+##' oopt = ani.options(interval = 0.1, nmax = ifelse(interactive(), 50, 2))
+##' par(mar = c(2, 3, 1, 0.5), mgp = c(1.5, 0.5, 0))
 ##' mwar.ani(lty.rect = 3, pch = 21, col = "red", bg = "yellow",type='o')
 ##'
-##' # for the data 'pageview'
-##' ani.options(interval = 0.1, nmax = 50)
+##' ## for the data 'pageview'
 ##' data(pageview)
 ##' mwar.ani(pageview$visits, k = 30)
 ##'
-##' par(op)
-##'
-##' \dontrun{
-##' # HTML animation page
-##' ani.options(ani.height = 500, ani.width = 600, nmax = 50,
-##'     title = "Demonstration of Moving Window Auto-Regression",
-##'     description = "Compute the AR(1) coefficient for the data in the
-##'     window and plot the confidence intervals. Repeat this step as the
-##'     window moves.")
-##' ani.start()
+##' ## HTML animation page
+##' saveHTML({
+##' ani.options(interval = 0.1, nmax = ifelse(interactive(), 50, 2))
 ##' par(mar = c(2, 3, 1, 0.5), mgp = c(1.5, 0.5, 0))
 ##' mwar.ani(lty.rect = 3, pch = 21, col = "red", bg = "yellow",type='o')
-##' ani.stop()
-##' }
+##' }, img.name='mwar.ani',htmlfile='mwar.ani.html',
+##' ani.height = 500, ani.width = 600,
+##'     title = "Demonstration of Moving Window Auto-Regression",
+##'     description = c("Compute the AR(1) coefficient for the data in the",
+##'     "window and plot the confidence intervals. Repeat this step as the",
+##'     "window moves."))
 ##'
 ##' ani.options(oopt)
 ##'
@@ -61,7 +60,6 @@ mwar.ani = function(x, k = 15, conf = 2, mat = matrix(1:2,
     2), widths = rep(1, ncol(mat)), heights = rep(1, nrow(mat)),
     lty.rect = 2, ...) {
     nmax = ani.options("nmax")
-    interval = ani.options("interval")
     if (missing(x))
         x = sin(seq(0, 2 * pi, length = 50)) + rnorm(50, sd = 0.2)
     n = length(x)
@@ -98,9 +96,8 @@ mwar.ani = function(x, k = 15, conf = 2, mat = matrix(1:2,
             angle = 90, code = 3, length = par("din")[1]/n *
                 0.4, col = 1:i)
         points(1:i + k/2 - 0.5, phi[1:i], ...)
-        Sys.sleep(interval)
+        ani.pause()
         j = j + 1
     }
-    ani.options(nmax = j - 1)
     invisible(list(phi = phi, lower = L, upper = U))
 }
